@@ -5,9 +5,10 @@ use std::process::exit;
 use std::sync::Mutex;
 use std::time::Instant;
 
-use crate::util::number::f64_to_i32;
-
-use crate::primes::{Calcit, CalcitItems};
+use crate::{
+  primes::{Calcit, CalcitItems},
+  util::number::f64_to_i32,
+};
 
 #[derive(Clone, Debug)]
 pub enum CliRunningMode {
